<?php
namespace Billing;

Class Aaio implements IPayment
{
    public string $doc = "https://wiki.aaio.so";
    
    public function Settings(array $config) : array
    {
        $html = array();
        
        $html[] = array(
            'ID Вашего магазина',
            'Для формы оплаты',
            '<input name="save_con[merchant_id]" class="form-control" type="text" value="' . $config['merchant_id'] . '" style="width: 100%">',
        );
        
        $html[] = array(
            'Секретный ключ №1',
            'Для формы оплаты',
            '<input name="save_con[secret_1]" class="form-control" type="text" value="' . $config['secret_1'] . '" style="width: 100%">',
        );
        
        $html[] = array(
            'Секретный ключ №2',
            'Для обработчика',
            '<input name="save_con[secret_2]" class="form-control" type="text" value="' . $config['secret_2'] . '" style="width: 100%">',
        );
        
        $html[] = [
            'Валюта',
            'Для формы оплаты',
            '<select name="save_con[currency]" class="form-control uniform">
                <option value="RUB" ' . ($config['currency'] == 'RUB' ? 'selected' : '') . '>RUB</option>
                <option value="USD" ' . ($config['currency'] == 'USD' ? 'selected' : '') . '>USD</option>
                <option value="EUR" ' . ($config['currency'] == 'EUR' ? 'selected' : '') . '>EUR</option>
                <option value="UAH" ' . ($config['currency'] == 'UAH' ? 'selected' : '') . '>UAH</option>
            </select>',
        ];
        
        $html[] = [
            'Язык',
            'Для формы оплаты',
            '<select name="save_con[lang]" class="form-control uniform">
                <option value="ru" ' . ($config['lang'] == 'ru' ? 'selected' : '') . '>Русский</option>
                <option value="en" ' . ($config['lang'] == 'en' ? 'selected' : '') . '>Английский</option>
            </select>',
        ];

        return $html;
    }
    
    public function check_payer_requisites(array $result) : string
    {
        return $result['email'] ?? '';
    }

    public function Form(int $id, array $config_payment, array $invoice, string $currency, string $desc): string
    {
        $config = $config_payment; // Rename for consistency if desired
        $description = $desc;

        $amount = number_format($invoice['invoice_pay'], 2, '.', '') * 1;

        if (empty($description)) {
            $description = 'Balance ' . $invoice['invoice_user_name'];
        }

        $forms = [
            'shop_id' => $config['shop_id'],
            'token' => $config['api_key'],
            'order_id' => $id,
            'amount' => $amount,
            'currency' => $currency // Include currency if needed
        ];

        $ch = curl_init('https://lk.rukassa.is/api/v1/create');
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($forms, '', '&'));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_HEADER, false);
        $result = json_decode(curl_exec($ch));
        curl_close($ch);

        if (!isset($result->id) || !isset($result->hash) || !isset($result->url)) {
            return "<a style='color=#ffffff'>" . $result->message . "</a>";
        }

        return "<a href=" . $result->url . " id='paysys_form' style='color=#ffffff'>Оплатить</a>";
    }

    // ... (rest of your class code)

    
    public function check_id(array $result) : int
    {
        return intval($result["order_id"]);
    }
    
    public function check_ok(array $result) : string
    {
        return 'OK';
    }
    
    public function check_out(array $data, array $config, array $invoice) : string|bool
    {
        global $_POST;
        
        // Проверка на IP адрес сервиса (по желанию)
        $ctx = stream_context_create([
            'http'=> [
                'timeout' => 10
            ]
        ]);

        $ips = json_decode(file_get_contents('https://aaio.so/api/public/ips', false, $ctx));
        if (isset($ips->list) && !in_array($this->getIP(), $ips->list)) {
            die("hacking attempt");
        }
        // Конец проверки на IP адрес сервиса

        $sign = hash('sha256', implode(':', [$_POST['merchant_id'], $_POST['amount'], $_POST['currency'], $config['secret_2'], $_POST['order_id']]));

        if (!hash_equals($_POST['sign'], $sign)) {
            die("wrong sign");
        }
        
        if($_POST['amount'] < $invoice['invoice_get']) {
            die("wrong amount");
        }

        if($_POST['currency'] !== $config['currency']) {
            die("wrong currency");
        }
        
        return 200;
    }
    
    private function getIP() : string
    {
        global $_SERVER;
        
        $ip = $_SERVER['REMOTE_ADDR'];
        
        if(isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
            $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
        }
        
        if(isset($_SERVER['HTTP_X_REAL_IP'])) {
            $ip = $_SERVER['HTTP_X_REAL_IP'];
        }
        
        if(isset($_SERVER['HTTP_CF_CONNECTING_IP'])) {
            $ip = $_SERVER['HTTP_CF_CONNECTING_IP'];
        }

        $explode = explode(',', $ip);
        
        if(count($explode) > 1) {
            $ip = trim($explode[0]);
        }
        
        return $ip;
    }
}

$Paysys = new Aaio;
?>